"""Interfaces for viewing components.
"""
from zope import schema
from zope.interface import Interface, Attribute
from waeup.sirp.interfaces import (
    IWAeUPObject, IUniversity, IUserContainer, IDataCenter)
from waeup.sirp.university.interfaces import (
    IFacultyContainer, IFaculty, IFacultyAdd, IDepartment, IDepartmentAdd, 
    ICourseContainer, ICourse, ICourseAdd, ICertificateContainer, 
    ICertificate, ICertificateAdd, ICertificateCourse, ICertificateCourseAdd)

class IBreadcrumb(Interface):
    """Provide breadcrumbs.
    """
    title = Attribute("Context description")
    viewname = Attribute("The viewname, for which the breadcrumb is provided.")
    parent_viewname = Attribute("The viewname of the parent to use.")
    parent = Attribute("The parent object.")
    context = Attribute("The context of the breadcrumb.")
    target = Attribute("The link target.")

class IBreadcrumbIgnorable(Interface):
    """A marker interface for breadcrumbs that should be skipped in output.

    If a breadcrumb wants to be skipped in real output (for instance,
    because it is set on a layer in site hierarchy that should not be
    accessed by users), it can also provide this interface. The
    getBreadcrumbList() function defined here will exclude IIgnorables
    by default.
    """
    pass

class IBreadcrumbContainer(Interface):
    """A container of breadcrumbs.
    """
    def __iter__():
        """Allow iteration over the container.
        """

    def getList():
        """Get the list of breadcrumbs as real Python list.
        """
class ITheme(Interface):
    """An theme or 'skin'.

    Themes are basically collections of CSS- and/or JavaScript files
    stored somewhere. In Grok-contexts these files can be registered
    as 'resources' (see :mod:`waeup.sirp.browser.resources`).

    Furthermore, to make themes selectable and distinctable from each
    other we assign them short descriptions.

    Themes should be registered as named utilities so that they can be
    defined also in third-party packages and be looked up by other
    components like theme-selectors.
    """
    description = schema.TextLine(
        title = u'Description',
        description = u'Short description of the theme for choice fields',
        required = False,
        )
        
    def getResources():
        """Get resources of the theme.

        Deliver a list of resources that must be included in a web page to
        let it be rendered in the theme's style.

        A resource is normally defined in the `resources` module. If a
        theme needs several of them which normally do not depend on
        each other then all these resources can be returned by this
        method. Normally, you will only return one resource.

        These resources will (if the theme is selected) be `need()`-ed
        by the `update()` method of the general site layout.
        """
